==> libmp3splt-0.7.tar.gz: libmp3splt-0.7/src/conversions.h <==
/**********************************************************
 *
 * libmp3splt -- library based on mp3splt,
 *               for mp3/ogg splitting without decoding
 *
 * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
 * Copyright (c) 2005-2011 Munteanu Alexandru - io_fx@yahoo.fr
 *
 * http://mp3splt.sourceforge.net
 *
 *********************************************************/

/**********************************************************
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307,
 * USA.
 *
 *********************************************************/

#ifndef SPLT_CONVERSIONS_H

long splt_co_convert_to_hundreths (const char *s);
float splt_co_convert_to_dB(double input);
double splt_co_convert_from_dB(float input);
void splt_co_get_mins_secs_hundr(long split_hundr, long *mins, long *secs, long *hundr);
long splt_co_time_to_long(double time);
long splt_co_time_to_long_ceil(double time);

#define SPLT_CONVERSIONS_H

#endif

==> libmp3splt-0.8.1a.tar.gz: libmp3splt-0.8.1a/src/conversions.h <==
/**********************************************************
 *
 * libmp3splt -- library based on mp3splt,
 *               for mp3/ogg splitting without decoding
 *
 * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
 * Copyright (c) 2005-2012 Alexandru Munteanu - m@ioalex.net
 *
 * http://mp3splt.sourceforge.net
 *
 *********************************************************/

/**********************************************************
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 *
 *********************************************************/

#ifndef SPLT_CONVERSIONS_H

long splt_co_convert_to_hundreths (const char *s);
float splt_co_convert_to_db(double input);
double splt_co_convert_from_db(float input);
void splt_co_get_mins_secs_hundr(long split_hundr, long *mins, long *secs, long *hundr);
long splt_co_time_to_long(double time);
long splt_co_time_to_long_ceil(double time);

#define SPLT_CONVERSIONS_H

#endif
